#include "Wire.h"
extern "C" { 
#include "utility/twi.h"  // from Wire library, so we can do bus scanning
}
#include "Adafruit_VL53L0X.h"
#include <LiquidCrystal_I2C.h>

#define TCAADDR 0x70

Adafruit_VL53L0X lox = Adafruit_VL53L0X();

LiquidCrystal_I2C lcd1(0x27,20,4); 
LiquidCrystal_I2C lcd2(0x27,20,4); 

void displayLCD (int channnel,LiquidCrystal_I2C & LCD);

void tcaselect(uint8_t i) 
{
  if (i > 7) return;
 
  Wire.beginTransmission(TCAADDR);
  Wire.write(1 << i);
  Wire.endTransmission();  
}

// standard Arduino setup()
void setup()
{

  Serial.begin(115200);
  
  while (!Serial);
  delay(1000);
  Wire.begin();

  tcaselect(2); //multiplexer select SD2 (SD3 & SD1 deselected)
  lcd1.init();
  lcd1.backlight();
  
  tcaselect(3); //multiplexer select SD3 (SD2 & SD1 deselected)
  lcd2.init();
  lcd2.backlight();

  Serial.print("Start.");
  
  tcaselect(1);//multiplexer select SD1 (SD2 & SD3 deselected)
  if (!lox.begin()) 
  {
    Serial.println(F("Failed to boot VL53L0X"));
    while(1);
  }
  
  Serial.println(" End setup");
  delay(2000);
}

void loop() 
{
  VL53L0X_RangingMeasurementData_t measure;
  
  tcaselect(1); //multiplexer select SD1 and SC1 and read the distance sensor
  lox.rangingTest(&measure, false); // pass in 'true' to get debug data printout!

  if (measure.RangeStatus != 4) {  // phase failures have incorrect data
    Serial.print("L1: "); Serial.print(measure.RangeMilliMeter);Serial.print(" ");
  } else {
    Serial.print("L1: "); Serial.print("OOR");Serial.print(" ");
  }
  
  Serial.println("");
    
  tcaselect(2); //multiplexer select SD2 and SC2 and display value on LCD1
  lcd1.clear();
  lcd1.setCursor(0,0);
  lcd1.print("VL53L0X_READ: ");
  lcd1.setCursor(0,1);
  lcd1.print(" ");
  lcd1.print(measure.RangeMilliMeter);
  
  
  tcaselect(3); //multiplexer select SD3 and SC3 and display value on LCD2
  lcd2.clear();
  lcd2.setCursor(0,0);
  lcd2.print("VL53L0X_READ: ");
  lcd2.setCursor(0,1);
  lcd2.print(" ");
  lcd2.print(measure.RangeMilliMeter);
  
  delay(1000);
   
}
